@@ -138,6 +138,18 @@ def main(argv=sys.argv[1:]):
         default=None,
         help='output filename, defaults to stdout',
     )
+    do_report.add_argument(
+        '--no-show-source',
+        dest='show_source',
+        default=True,
+        action='store_false',
+        help='do not show the source for notes',
+    )
+    do_report.add_argument(
+        '--title',
+        default='Release Notes',
+        help='set the main title of the generated report',
+    )
     _build_query_arg_group(do_report)
     do_report.set_defaults(func=report.report_cmd)
 
